@@ -443,6 +443,11 @@ class CursorTests(ConnectingTestCase):
         self.assertEqual([(2,), (3,), (4,)], cur2.fetchmany(3))
         self.assertEqual([(5,), (6,), (7,)], cur2.fetchall())
 
+    @skip_before_postgres(8, 0)
+    def test_named_noop_close(self):
+        cur = self.conn.cursor('test')
+        cur.close()
+
     @skip_before_postgres(8, 0)
     def test_scroll(self):
         cur = self.conn.cursor()
@@ -567,7 +572,7 @@ class CursorTests(ConnectingTestCase):
         # Issue #443 is in the async code too. Since the fix is duplicated,
         # so is the test.
         control_conn = self.conn
-        connect_func = lambda: self.connect(async=True)
+        connect_func = lambda: self.connect(async_=True)
         wait_func = psycopg2.extras.wait_select
         self._test_external_close(control_conn, connect_func, wait_func)
 
